""" Code is generated by ucloud-model, DO NOT EDIT IT. """

from ucloud.core.typesystem import schema, fields


class UFSVolumeInfo2Schema(schema.ResponseSchema):
    """UFSVolumeInfo2 - 文件系统信息"""

    fields = {
        "CreateTime": fields.Int(required=False, load_from="CreateTime"),
        "ExpiredTime": fields.Int(required=False, load_from="ExpiredTime"),
        "IsExpired": fields.Str(required=False, load_from="IsExpired"),
        "MaxMountPointNum": fields.Int(
            required=True, load_from="MaxMountPointNum"
        ),
        "ProtocolType": fields.Str(required=True, load_from="ProtocolType"),
        "Remark": fields.Str(required=False, load_from="Remark"),
        "Size": fields.Int(required=False, load_from="Size"),
        "StorageType": fields.Str(required=True, load_from="StorageType"),
        "Tag": fields.Str(required=False, load_from="Tag"),
        "TotalMountPointNum": fields.Int(
            required=True, load_from="TotalMountPointNum"
        ),
        "UsedSize": fields.Int(required=False, load_from="UsedSize"),
        "VolumeId": fields.Str(required=True, load_from="VolumeId"),
        "VolumeName": fields.Str(required=True, load_from="VolumeName"),
    }
